Boost logo

Boost-Commit :

Subject: [Boost-commit] svn:boost r56087 - trunk/boost/spirit/home/lex/lexer
From: hartmut.kaiser_at_[hidden]
Date: 2009-09-07 10:44:20


Author: hkaiser
Date: 2009-09-07 10:44:19 EDT (Mon, 07 Sep 2009)
New Revision: 56087
URL: http://svn.boost.org/trac/boost/changeset/56087

Log:
Spirit: removed lex::omitted in favor of lex::omit
Text files modified:
   trunk/boost/spirit/home/lex/lexer/token_def.hpp | 4 ++--
   1 files changed, 2 insertions(+), 2 deletions(-)

Modified: trunk/boost/spirit/home/lex/lexer/token_def.hpp
==============================================================================
--- trunk/boost/spirit/home/lex/lexer/token_def.hpp (original)
+++ trunk/boost/spirit/home/lex/lexer/token_def.hpp 2009-09-07 10:44:19 EDT (Mon, 07 Sep 2009)
@@ -97,12 +97,12 @@
             // The return value of the token_def is either the specified
             // attribute type, or the pair of iterators from the match of the
             // corresponding token (if no attribute type has been specified),
// or unused_type (if omitted has been specified).
             typedef typename Iterator::base_iterator_type iterator_type;
             typedef typename mpl::if_<
                 traits::is_not_unused<Attribute>
               , typename mpl::if_<
- is_same<Attribute, omitted>, unused_type, Attribute
+ is_same<Attribute, omit>, unused_type, Attribute
>::type
               , iterator_range<iterator_type>
>::type type;
@@ -97,12 +97,12 @@
             // attribute type, or the pair of iterators from the match of the
             // corresponding token (if no attribute type has been specified),
- // or unused_type (if omitted has been specified).
+ // or unused_type (if omit has been specified).
             typedef typename Iterator::base_iterator_type iterator_type;
             typedef typename mpl::if_<


Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk